pydmr
=====


.. image:: https://img.shields.io/badge/License-Apache_2.0-blue.svg
  :target: https://opensource.org/licenses/Apache-2.0



A python interface for the dmr data format
------------------------------------------

- **Documentation:** https://openmiblab.github.io/pydmr/
- **Source code:** https://github.com/openmiblab/pydmr


Installation
------------

.. code-block:: console

    pip install pydmr


License
-------

Released under the `Apache 2.0 <https://opensource.org/licenses/Apache-2.0>`_  
license::

  Copyright (C) 2025 pydmr developers

